#!/bin/tcsh

# Phil Carns
# pcarns@hubcap.clemson.edu
#
# This is a simple script that can be used to prepare slave nodes in
# the Scyld Beowulf distribution to run PVFS.  This only needs to be
# run *once*  unless you format a slave node and need to reinstall it.
# You should also have a  companion script to this one that his actually
# used to start the daemons on bootup.

# Edit these variables to suit your configuration:
set PVFS_IOD_DATA_DIR="/pvfs_data"
set PVFS_CLIENT_MOUNT_DIR="/mnt/pvfs"

if $1 == "" then
	echo "usage: pvfs_slave_create.sh [a | l | #]"
	echo "(perform the action on the specified node, a for all, l for localhost)"
	exit -1
endif

if $1 == "a" then

	# this is for the slave node client access
	bpsh -A mknod /dev/pvfsd c 60 0
	bpsh -A mkdir -p $PVFS_CLIENT_MOUNT_DIR

	# this is the data dir for the iod
	bpsh -A mkdir -p $PVFS_IOD_DATA_DIR

	# and this is for local node client access
	mknod /dev/pvfsd c 60 0
	mkdir -p $PVFS_CLIENT_MOUNT_DIR

else if $1 == "l" then

	# and this is for local node client access
	mknod /dev/pvfsd c 60 0
	mkdir -p $PVFS_CLIENT_MOUNT_DIR

else 

	# this is for the slave node client access
	bpsh $1 mknod /dev/pvfsd c 60 0
	bpsh $1 mkdir -p $PVFS_CLIENT_MOUNT_DIR

	# this is the data dir for the iod
	bpsh $1 mkdir -p $PVFS_IOD_DATA_DIR

endif



